<?php
// +---------------------------------------------------------------------------+
// | Chameleon                                                                 |
// +---------------------------------------------------------------------------+
// | $Id:: install.php 12 2007-11-16 11:11:23Z mark                           $|
// | install.php                                                               |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2007 by the following authors:                              |
// |                                                                           |
// | Author: Mark R. Evans - mevans@ecsnet.com                                 |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+
//
require_once('../../../lib-common.php');
require_once($_CONF['path'] . '/plugins/chameleon/config.php');
require_once($_CONF['path'] . '/plugins/chameleon/functions.inc');

$pi_name    = 'chameleon';              // Plugin name
$pi_version = $_CN_CONF['version'];     // Plugin Version
$gl_version = '1.5.1';                  // GL Version plugin for
$pi_url     = 'http://hiroron.com';  // Plugin Homepage

if (!SEC_inGroup('Root')) {
    // Someone is trying to illegally access this page
    COM_errorLog("Someone has tried to illegally access the Chameleon install/uninstall page.  User id: {$_USER['uid']}, Username: {$_USER['username']}, IP: $REMOTE_ADDR",1);
    $display = COM_siteHeader();
    $display .= COM_startBlock($LANG_CN00['access_denied']);
    $display .= $LANG_CN00['access_denied_msg'];
    $display .= COM_endBlock();
    $display .= COM_siteFooter(true);
    echo $display;
    exit;
}

function plugin_install_chameleon()
{
    global $pi_name, $pi_version, $gl_version, $pi_url;
    global $_TABLES, $_CONF, $LANG_CN00, $_DB_dbms;

    COM_errorLog("Attempting to install the $pi_name Plugin",1);

    // create Chameleon tables
    $_SQL['cn_settings'] = "CREATE TABLE `{$_TABLES['cn_settings']}` ( " .
                "`layout` int(11) NOT NULL default '1', " .
                "`color` int(11) NOT NULL default '1', " .
                "`lblock` int(11) NOT NULL default '1', " .
                "`rblock` int(11) NOT NULL default '1', " .
                "`menu` int(11) NOT NULL default '1', " .
                "`menualign` int(11) NOT NULL default '1', " .
                "`logo` int(11) NOT NULL default '1', " .
                "`slogan` tinyint(4) NOT NULL default '1' " .
                ");";

    $_SQL['cn_styles'] = "CREATE TABLE `{$_TABLES['cn_styles']}` ( " .
                "`id` int(11) NOT NULL auto_increment, " .
                "`type` varchar(25) NOT NULL, " .
                "`name` varchar(128) NOT NULL, " .
                "`description` varchar(255) NOT NULL, " .
                "PRIMARY KEY  (`id`), " .
                "KEY `type` (`type`) " .
                ");";

    foreach ($_SQL as $table => $sql) {
        COM_errorLog("Creating $table table",1);
        DB_query($sql,1);
        if (DB_error()) {
            COM_errorLog("Error Creating $table table",1);
            plugin_uninstall_chameleon();
            return false;
            exit;
        }
        COM_errorLog("Success - Created $table table",1);
    }

    // insert default record into db
    DB_query("INSERT INTO {$_TABLES['cn_settings']} (layout,color,lblock,rblock,menu,menualign,logo,slogan) " .
             "VALUES (1,36,30,33,18,1,1,1)");

    if ( DB_error()) {
        COM_errorLog("Chameleon: Failure creating initial settings record.");
        plugin_uninstall_chameleon();
        return false;
        exit;
    }

    // insert default styles
    $_SQL['default_styles']="INSERT INTO {$_TABLES['cn_styles']} (`id`, `type`, `name`, `description`) VALUES " .
                "(1, 'layout', 'Layout 1', 'Fluid center content column with fixed navigation and extra columns')," .
                "(2, 'layout', 'Layout 2', 'Fluid content on left with navigation and extra columns on the right')," .
                "(3, 'layout', 'Layout 3', 'Fluid content on right with navigation and extra columns on the left')," .
                "(4, 'layout', 'Layout 4', 'Navigation and Extra columns are stacked and floated right of the content')," .
                "(5, 'layout', 'Layout 5', 'Navigation and Extra columns are stacked and floated left of the content')," .
                "(6, 'layout', 'Layout 6', 'Fixed navigation on right with fluid content and fluid extras below both')," .
                "(7, 'layout', 'Layout 7', 'Fixed navigation on left with fluid content and fluid extras below both')," .
                "(8, 'layout', 'Layout 8', 'Fixed center content column with fixed navigation and extra columns ')," .
                "(9, 'layout', 'Layout 9', 'Fixed content column with fixed navigation and extra columns floated right')," .
                "(10, 'layout', 'Layout 10', 'Fixed content column with fixed navigation and extra columns floated left')," .
                "(11, 'layout', 'Layout 11', 'Fixed content column with fixed navigation and extra columns stacked right')," .
                "(12, 'layout', 'Layout 12', 'Fixed content column with fixed navigation and extra columns stacked left')," .
                "(13, 'layout', 'Layout 13', 'Fixed content column with fixed extra below and navigation floated right ')," .
                "(14, 'layout', 'Layout 14', 'Fixed content column with fixed extra below and navigation floated left')," .
                "(15, 'layout', 'Layout 15', 'Fixed content column with navigation floated right with extras below both')," .
                "(16, 'layout', 'Layout 16', 'Fixed content column with navigation floated left with extras below both')," .
                "(17, 'layout', 'Layout 17', 'Fixed content column with navigation and extra columns below')," .
                "(44, 'layout', 'Layout 18', 'Fluid content column with fluid extra below and navigation fixed left')," .
                "(45, 'layout', 'Layout 19', 'Fluid content column with fluid extra below and navigation fixed right')," .
                "(46, 'layout', 'Layout 20', 'Fluid content column with navigation and extra columns below')," .
                "(18, 'menu', 'Menu 1', 'Silver Buttons')," .
                "(19, 'menu', 'Menu 2', 'Grey with slanted dividers')," .
                "(20, 'menu', 'Menu 3', 'Silver bg with black highlight and bottom divider bar')," .
                "(21, 'menu', 'Menu 4', 'Thin menu with hover')," .
                "(22, 'menu', 'Menu 5', 'Blue Buttons with black highlight')," .
                "(23, 'menu', 'Menu 6', 'Black bar with blue underline highlight')," .
                "(24, 'menu', 'Menu 7', 'Black glass tabs on dark background')," .
                "(25, 'menu', 'Menu 8', 'Dark menu with rounded retro highlight')," .
                "(26, 'menu', 'Menu 9', 'Smooth blue tabs on black background')," .
                "(27, 'menu', 'Menu 10', 'Blue glass tabs with a border')," .
                "(28, 'menu', 'Menu 11', 'Large fixed-size block with rounded hover')," .
                "(29, 'menu', 'Menu 12', 'Transparent button background with alpha shaded highlight')," .
                "(30, 'lblock', 'Shaded Title BG', 'Block with shaded title background')," .
                "(31, 'lblock', 'No Title Shading', 'Block with bold title - no title background shading')," .
                "(32, 'lblock', 'No Title', 'No block title at all')," .
                "(33, 'rblock', 'Shaded Title BG', 'Block with shaded title background')," .
                "(34, 'rblock', 'No Title Shading', 'Block with bold title - no title background shading')," .
                "(35, 'rblock', 'No Title', 'No block title at all')," .
                "(36, 'color', 'Light Blue', 'Light blue color scheme')," .
                "(37, 'color', 'Dark Blue', 'Dark blue color scheme')," .
                "(38, 'color', 'Light Green', 'Light Green Theme')," .
                "(39, 'color', 'Dark Green', 'Dark Green Theme')," .
                "(40, 'color', 'Light Purple', 'Light purple color style')," .
                "(41, 'color', 'Dark Purple', 'Dark purple color style')," .
                "(42, 'color', 'Light Red', 'Light red color style')," .
                "(43, 'color', 'Dark Red', 'Dark red color scheme');";

    DB_query($_SQL['default_styles']);

    if ( DB_error()) {
        COM_errorLog("Chameleon: Failure creating layout record in gl_vars table.");
        plugin_uninstall_chameleon();
        return false;
        exit;
    }

    // Register the plugin with Geeklog
    COM_errorLog("Registering $pi_name plugin with Geeklog", 1);
    DB_delete($_TABLES['plugins'],'pi_name','chameleon');
    DB_query("INSERT INTO {$_TABLES['plugins']} " .
             "(pi_name, pi_version, pi_gl_version, pi_homepage, pi_enabled) " .
             "VALUES ('$pi_name', '$pi_version', '$gl_version', '$pi_url', 1)");

    if (DB_error()) {
        COM_errorLog("Chameleon: Failure registering plugin with Geeklog");
        plugin_uninstall_chameleon();
        return false;
        exit;
    }
    COM_errorLog("Successfully installed the $pi_name Plugin!",1);
    return true;
}

/*
* Main Function
*/

$action = COM_applyFilter($_POST['action']);

$display = COM_siteHeader();
$T = new Template($_CONF['path'] . 'plugins/chameleon/templates');
$T->set_file('install', 'install.thtml');
$T->set_var('install_header', $LANG_CN00['install_header']);
$T->set_var('img',$_CONF['site_admin_url'] . '/plugins/chameleon/chameleon.png');
$T->set_var('cgiurl', $_CONF['site_admin_url'] . '/plugins/chameleon/install.php');
$T->set_var('admin_url', $_CONF['site_admin_url'] . '/plugins/chameleon/index.php');

if ($action == 'install') {
    if (plugin_install_chameleon()) {
        $installMsg = sprintf($LANG_CN00['install_success'],
                              $_CONF['site_admin_url'] .
                                '/plugins/chameleon/index.php');
        $T->set_var('installmsg1',$installMsg);
    } else {
       	echo COM_refresh ($_CONF['site_admin_url'] . '/plugins.php?msg=72');
    }
} else if ($action == "uninstall") {
   plugin_uninstall_chameleon('installed');
   $T->set_var('installmsg1',$LANG_CN00['uninstall_msg']);
}

if (DB_count($_TABLES['plugins'], 'pi_name', 'chameleon') == 0) {
    $T->set_var('installmsg2', $LANG_CN00['uninstalled']);
    $T->set_var('readme', $LANG_CN00['readme']);
    $T->set_var('btnmsg', $LANG_CN00['install']);
    $T->set_var('action','install');

    $glVersionOK = 1;

    $glversion = explode(".", VERSION);
    if ( $glversion[0] < 1 ) {
        $glVersionOK = 0;
    } else if ($glversion[1] < 5 ) {
        $glVersionOK = 0;
    } else if ($glversion[2] < 1 ) {
        $glVersionOK = 0;
    }

    $gl_version = VERSION;
    $php_version = phpversion();

    $glver = sprintf($LANG_CN00['geeklog_check'],$gl_version);

    if ( $glVersionOK == 0 ) {
        $glver = $glver . ' <span class="b">Geeklog Version is too old</span>';
    }

    $phpver = sprintf($LANG_CN00['php_check'],$php_version);
    $T->set_var(array(
        'lang_overview'     => $LANG_CN00['overview'],
        'lang_details'      => $LANG_CN00['details'],
        'requirements'      => $LANG_CN00['preinstall_check'],
        'gl_version'        => $glver,
        'php_version'       => $phpver,
        'install_doc'       => $LANG_CN00['preinstall_confirm'],
    ));
} else {
    echo COM_refresh($_CONF['site_url'] . '/index.php?msg=1&amp;plugin=chameleon');
    exit;
}
$T->parse('output','install');
$display .= $T->finish($T->get_var('output'));
$display .= COM_siteFooter(true);

echo $display;

?>