<?php
// +---------------------------------------------------------------------------+
// | Chameleon Morphing Theme for Geeklog v1.5                                 |
// +---------------------------------------------------------------------------+
// | $Id:: functions.inc 19 2007-11-17 07:01:12Z mark                         $|
// | Geeklog integration functions.                                            |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2007 by the following authors:                              |
// |                                                                           |
// | Author: Mark R. Evans - mevans@ecsnet.com                                 |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+
//

// this file can't be used on its own
if (strpos (strtolower($_SERVER['PHP_SELF']), 'functions.inc') !== false)
{
    die ('This file can not be used on its own.');
}

$langfile = $_CONF['path'] . 'plugins/chameleon/language/' . $_CONF['language'] . '.php';

if (file_exists ($langfile)) {
    include_once ($langfile);
} else {
    include_once ($_CONF['path'] . 'plugins/chameleon/language/english.php');
}
/*
* Include Chameleon config file
*/
require_once($_CONF['path'] . 'plugins/chameleon/config.php');

function plugin_chkVersion_chameleon() {
    global $_CN_CONF;

    return $_CN_CONF['version'];
}

/**
* This will put an option for the plugin in the command and control block on moderation.php
*
* Add the plugin name, icon and link to the command and control block in moderation.php
*
* @return   array   Array containing (plugin name, admin url, url of plugin icon)
*
*/

function plugin_cclabel_chameleon() {
    global $_CONF, $_CN_CONF, $LANG_CN00;

    if (SEC_inGroup('Root') ) {
        return array($LANG_CN00['menulabel'],
            $_CONF['site_admin_url'] . '/plugins/chameleon/index.php',
            $_CONF['site_admin_url'] . '/plugins/chameleon/chameleon.png');
    } else {
        return '';
    }
}

/**
* Returns the administrative option for this plugin
*
* Adds the plugin to the Admin menu
*
* @return   array   Array containing (plugin name, plugin admin url, # of items in plugin or '')
*
*/
function plugin_getadminoption_chameleon() {
    global $_CONF, $_TABLES, $LANG_CN00, $_CN_CONF;

    if (SEC_inGroup('Root')) {
        return array($LANG_CN00['menulabel'], $_CONF['site_admin_url'] . '/plugins/chameleon/index.php', 0);
    }
}

/**
* Removes the data structures for this plugin from the Geeklog database.
* This routine will get called from the Plugin install program if user select De-Install or if Delete is used in the Plugin Editor.
* The Plugin Installer will also call this routine upon and install error to remove anything it has created.
* The Plugin installer will pass the optional parameter which will then double check that plugin has first been disabled.
*
* For this plugin, this routine will also remove the Block definition.
*
* Returns True if all Plugin related data is removed without error
*
* @param    string   $installCheck     Defult is blank but if set, check if plugin is disabled first
*
* @return   boolean True if successful false otherwise
*
*/
function plugin_uninstall_chameleon($installCheck='') {
    global $_CONF, $_USER, $_TABLES, $LANG_CN00, $_DB_table_prefix;

    $pi_name    = 'chameleon';
    $TABLES     = array ( 'cn_settings','cn_styles');
    $display    = '';

    // Check and see if plugin is still enabled - if so display warning and exit
    if ($installCheck != '' && DB_getItem($_TABLES['plugins'],'pi_enabled', 'pi_name = "' .$pi_name. '"')) {
        COM_errorLog("Plugin is installed and enabled. Disable first if you want to de-install it",1);
        $display .= COM_startBlock($LANG_CN00['warning']);
        $display .= $LANG_CN00['enabled'];
        $display .= COM_endBlock();
        echo $display;
        return false;
        exit;
    }

    if ( $_USER['theme'] == 'chameleon' ) {
        $display .= COM_startBlock($LANG_CN00['warning']);
        $display .= '<b>You cannot delete the chameleon plugin if it is your active theme</b>';
        $display .= COM_endBlock();
        echo $display;
        return false;
        exit;
    }

    if ( $_CONF['theme'] == 'chameleon' ) {
        $display .= COM_startBlock($LANG_CN00['warning']);
        $display .= '<b>You cannot delete the chameleon plugin because it is setup as the default theme in your config.php.</b>';
        $display .= COM_endBlock();
        echo $display;
        return false;
        exit;
    }

    DB_query("UPDATE {$_TABLES['users']} SET theme='' WHERE theme='chameleon'");
    $_USER['theme'] = 'professional';

    // Drop chameleon tables
    foreach($TABLES as $table) {
        COM_errorLog("Removing Table $table",1);
        DB_query("DROP TABLE " . $_DB_table_prefix . $table,1);
    }
    DB_query("DELETE FROM {$_TABLES['vars']} WHERE name='chameleon'",1);

    // Unregister the plugin with Geeklog
    COM_errorLog('Attempting to unregister the Chameleon Plugin from Geeklog',1);
    DB_query("DELETE FROM {$_TABLES['plugins']} WHERE pi_name = 'chameleon'",1);

    COM_errorLog('...success',1);
    return true;
}

function plugin_upgrade_chameleon()
{
    global $_TABLES, $_CONF, $_CN_CONF;

    $currentVersion = DB_getItem($_TABLES['plugins'],'pi_version',"pi_name='chameleon'");

    switch( $currentVersion ) {
        case '1.0.0' :
        case '1.0.1' :
        case '1.0.2' :
        case '1.0.3' :
            $sql = "INSERT INTO {$_TABLES['cn_styles']} (`id`, `type`, `name`, `description`) VALUES " .
                    "(44, 'layout', 'Layout 18', 'Fluid content column with fluid extra below and navigation fixed left')," .
                    "(45, 'layout', 'Layout 19', 'Fluid content column with fluid extra below and navigation fixed right')," .
                    "(46, 'layout', 'Layout 20', 'Fluid content column with navigation and extra columns below');";
            DB_query($sql,1);
        default :
            DB_query("UPDATE {$_TABLES['plugins']} SET pi_version='".$_CN_CONF['version']."',pi_homepage='http://hiroron.com' WHERE pi_name='chameleon' LIMIT 1");
            break;
    }
    if ( DB_getItem($_TABLES['plugins'],'pi_version',"pi_name='chameleon'") == $_CN_CONF['version']) {
        return 2;
    } else {
        return 3;
    }
}

function chameleon_statusMessage($message='',$url,$prompt) {
    global $_CONF,$_CN_CONF,$LANG_CN02;

    $statusmsg = new Template($_CONF['path'] . 'plugins/chameleon/templates');
    $statusmsg->set_file (array ('statusmsg'=>'statusmessage.thtml'));
    $statusmsg->set_var ('heading', $LANG_CN02['status_header']);
    $statusmsg->set_var ('message', $message);
    if ($_CN_CONF['use_autorefresh'] == "0") {
        $statusmsg->set_var ('prompt',sprintf($LANG_CN02['default_msg'],$prompt,$url));
        $statusmsg->set_var('autoredirect_javascript','');
    } else {
        $autorefresh_delay = $_CN_CONF['autorefresh_delay'] * 10000;
        $statusmsg->set_var('autoredirect_javascript',
            "\n\n<script type=\"text/javascript\">\nwindow.setTimeout(\"window.location.href='{$url}'\",{$autorefresh_delay});\n</script>\n\n");
        $prompt = sprintf($LANG_CN02['auto_refresh'],$url);
        $statusmsg->set_var ('prompt',$prompt);
    }
    $statusmsg->parse ('output', 'statusmsg');
    $retval = $statusmsg->finish ($statusmsg->get_var('output'));

    return $retval;
}
?>